@@ -16,6 +16,9 @@
 Sparsifying dictionaries
 """
 
+# pylint: disable=W0611
+
+
 from cr.sparse._src.dict.simple import (
     gaussian_mtx,
     rademacher_mtx,
@@ -23,20 +26,24 @@ from cr.sparse._src.dict.simple import (
     hadamard,
     hadamard_basis,
     dirac_hadamard_basis,
-    dct_basis,
-    dirac_dct_basis,
-    dirac_hadamard_dct_basis,
-    fourier_basis
+    cosine_basis,
+    dirac_cosine_basis,
+    dirac_hadamard_cosine_basis,
+    fourier_basis,
+    random_orthonormal_rows
 )
 
 from cr.sparse._src.dict.props import (
     gram,
+    frame,
     coherence_with_index,
     coherence,
     frame_bounds,
     upper_frame_bound,
     lower_frame_bound,
-    babel
+    babel,
+    mutual_coherence_with_index,
+    mutual_coherence,
 )
 
 from cr.sparse._src.dict.comparison import (
