@@ -12,6 +12,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+"""
+Iterative Hard Thresholding
+"""
+# pylint: disable=W0611
+
+
 from cr.sparse._src.pursuit.iht import (
-    solve
+    solve,
+    matrix_solve,
+    matrix_solve_jit,
+    operator_solve,
+    operator_solve_jit,
 )
