@@ -12,7 +12,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+"""
+Orthogonal Matching Pursuit
+"""
+# pylint: disable=W0611
+
+
 from cr.sparse._src.pursuit.omp import (
     solve,
-    solve_multi
+    matrix_solve,
+    matrix_solve_jit,
+    matrix_solve_multi,
 )
