@@ -12,6 +12,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+"""
+Phase Transition Analysis Utilities
+"""
+
+# pylint: disable=W0611
+
+
 from cr.sparse._src.pursuit.phasetransition import (
     configuration
 )
