@@ -12,6 +12,18 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+"""
+Subspace Pursuit
+"""
+
+# pylint: disable=W0611
+
+
 from cr.sparse._src.pursuit.sp import (
-    solve
+    solve,
+    matrix_solve,
+    matrix_solve_jit,
+    operator_solve,
+    operator_solve_jit,
+
 )
